@@ -1,8 +1,20 @@
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
+# implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import logging
 import time
 
 import eventlet
-
 from ironicclient import exceptions
 
 from ironic_discoverd import conf
@@ -106,6 +118,10 @@ def process(node_info):
         LOG.error('Node is not on discovery, cannot proceed')
         return
 
+    _process_node(ironic, node, node_info, valid_macs)
+
+
+def _process_node(ironic, node, node_info, valid_macs):
     patch = [{'op': 'add', 'path': '/extra/newly_discovered', 'value': 'true'},
              {'op': 'remove', 'path': '/extra/on_discovery'}]
     existing = node.properties
